:orphan:



.. _sphx_glr__gallery:

.. This directory contains scripts to use as tutorials to understand the package
   Use plot_*.py for script that intend to display some feature and will be
   rendered in the package gallery

Gallery
=======

Example plots of available features



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Plot measures from figure 1 and model evaluation using raw formalisms">

.. only:: html

 .. figure:: /_gallery/images/thumb/sphx_glr_plot_fig1_thumb.png
     :alt: Figure 1

     :ref:`sphx_glr__gallery_plot_fig1.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /_gallery/plot_fig1

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Plot formalisms using parameter values from fig3 (table1)">

.. only:: html

 .. figure:: /_gallery/images/thumb/sphx_glr_plot_fig3_thumb.png
     :alt: Figure 3

     :ref:`sphx_glr__gallery_plot_fig3.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /_gallery/plot_fig3

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Plot formalisms using parameter values from table1">

.. only:: html

 .. figure:: /_gallery/images/thumb/sphx_glr_plot_fig8_thumb.png
     :alt: Figure 9

     :ref:`sphx_glr__gallery_plot_fig8.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /_gallery/plot_fig8
.. raw:: html

    <div class="sphx-glr-clear"></div>



.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
